local AddonName, AddonTable = ...
local L = AddonTable.Localize
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")

local GTWelcome = CreateFrame("Frame")
GTWelcome:RegisterEvent("ADDON_LOADED")
GTWelcome:RegisterEvent("PLAYER_TARGET_CHANGED")

local function GTEventHandler(self, event, arg1)

if event == "ADDON_LOADED" and arg1 == "GuildTooltip" then
	if GTConfig == nil or GTConfig == "" then
		GTConfig = {
			["Colour"] = "ENABLED",
			["HealthBar"] = "ENABLED",
			["Titles"] = "ENABLED",
			["Realms"] = "ENABLED",
			["GuildRank"] = "DISABLED",
			["FontSize"] = "12"
		}
	end
	
	if GTConfig.HealthBar == nil then GTConfig.HealthBar = 'ENABLED' end
	if GTConfig.Titles == nil then GTConfig.Titles = 'ENABLED' end
	if GTConfig.Realms == nil then GTConfig.Realms = 'ENABLED' end
	if GTConfig.GuildRank == nil then GTConfig.GuildRank = 'DISABLED' end
	if GTConfig.FontSize == nil then GTConfig.FontSize = '12' end
elseif event == "PLAYER_TARGET_CHANGED" then
	if IsAddOnLoaded("ShadowedUnitFrames") == true then
		SUFUnittarget:SetScript("OnEnter", function(self)
			if UnitIsPlayer("target") and not UnitIsUnit("target", "player") then
				GameTooltip:Show()
				CreateGTTooltip("target")
			end
		end)
		
		SUFUnittarget:SetScript("OnLeave", function(self)
			if GTConfig.HealthBar == "ENABLED" then
				GameTooltipStatusBar:Hide()
			elseif GTConfig.HealthBar == "DISABLED" then
				GameTooltipStatusBar:Hide()
			end
	
			GameTooltipHeaderText:SetFont("Fonts\\FRIZQT__.ttf", 14)
		end)
	end
end

end

GTWelcome:SetScript("OnEvent", GTEventHandler)

-- Game Tooltip

GameTooltip:HookScript("OnTooltipSetUnit", function(self)
	if UnitIsPlayer("mouseover") and not UnitIsUnit("mouseover", "player") then
		CreateGTTooltip("mouseover")
	end
end)

GameTooltip:HookScript("OnTooltipCleared", function(self)
	if GTConfig.HealthBar == "ENABLED" then
		GameTooltipStatusBar:Hide()
	elseif GTConfig.HealthBar == "DISABLED" then
		GameTooltipStatusBar:Hide()
	end
	
	GameTooltipHeaderText:SetFont("Fonts\\FRIZQT__.ttf", 14)
end)

-- Target Frame

TargetFrame:HookScript("OnEnter", function(self)
	if UnitIsPlayer("target") and not UnitIsUnit("target", "player") then
		CreateGTTooltip("target")
	end
end)

TargetFrame:HookScript("OnLeave", function(self)
	if GTConfig.HealthBar == "ENABLED" then
		GameTooltipStatusBar:Hide()
	elseif GTConfig.HealthBar == "DISABLED" then
		GameTooltipStatusBar:Hide()
	end
	
	GameTooltipHeaderText:SetFont("Fonts\\FRIZQT__.ttf", 14)
	GameTooltip:Show()
end)

-- Party/Raid Frames
-- I doubt this will ever happen, as I can't get it working no matter what I try.


-- Tooltip Creation

function CreateGTTooltip(person)

GameTooltipHeaderText:SetFont("Fonts\\FRIZQT__.ttf", tonumber(GTConfig.FontSize))
	local guildName, guildRankName, guildRankIndex = GetGuildInfo(person);
	local playerlevel = UnitLevel(person)
	local race = UnitRace(person)
	local localizedClass, englishClass, classIndex = UnitClass(person)
	local myRealm = GetRealmName("player")
			
	local theirname, theirRealm = UnitName(person)
	local name
	
	if theirRealm ~= nil then
		if GTConfig.Realms == "DISABLED" then
			if GTConfig.Titles == "ENABLED" then
				name = UnitPVPName(person)
			elseif GTConfig.Titles == "DISABLED" then
				name = UnitName(person)
			end
		elseif GTConfig.Realms == "ENABLED" then
			if GTConfig.Titles == "ENABLED" then
				name = UnitPVPName(person) .. "-" .. theirRealm
			elseif GTConfig.Titles == "DISABLED" then
				name = UnitName(person) .. "-" .. theirRealm
			end
		end
	elseif theirRealm == myRealm or theirRealm == nil then
		if GTConfig.Titles == "ENABLED" then
			name = UnitPVPName(person)
		elseif GTConfig.Titles == "DISABLED" then
			name = UnitName(person)
		end
	end
	
	if playerlevel == -1 then playerlevel = "??" end
	
	if GTConfig.Colour == "ENABLED" then		
		if guildName == nil then
			GameTooltipTextLeft1:SetText("|c" .. RAID_CLASS_COLORS[englishClass].colorStr .. name .. "|r")
			GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " |c" .. RAID_CLASS_COLORS[englishClass].colorStr .. localizedClass .. "|r", 1, 1, 1, true)
		elseif guildName ~= nil then
			if GTConfig.GuildRank == "ENABLED" then
				GameTooltipTextLeft1:SetText("|c" .. RAID_CLASS_COLORS[englishClass].colorStr .. name .. "|r\n|cFF40FB40" .. guildRankName .. " of " .. guildName .. "|r")
				GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " |c" .. RAID_CLASS_COLORS[englishClass].colorStr .. localizedClass .. "|r", 1, 1, 1, true)
			elseif GTConfig.GuildRank == "DISABLED" then
				GameTooltipTextLeft1:SetText("|c" .. RAID_CLASS_COLORS[englishClass].colorStr .. name .. "|r\n|cFF40FB40" .. guildName .. "|r")
				GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " |c" .. RAID_CLASS_COLORS[englishClass].colorStr .. localizedClass .. "|r", 1, 1, 1, true)
			end
		end
	elseif GTConfig.Colour == "DISABLED" then
		if guildName == nil then
			GameTooltipTextLeft1:SetText(name)
			GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " " .. localizedClass, 1, 1, 1, true)
		elseif guildName ~= nil then
			if GTConfig.GuildRank == "ENABLED" then
				GameTooltipTextLeft1:SetText(name .. "\n" .. guildRankName .. " of " .. guildName)
				GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " " .. localizedClass, 1, 1, 1, true)
			elseif GTConfig.GuildRank == "DISABLED" then
				GameTooltipTextLeft1:SetText(name .. "\n" .. guildName)
				GameTooltipTextLeft2:SetText(LEVEL .. " " .. playerlevel .. " " .. race .. " " .. localizedClass, 1, 1, 1, true)
			end
		end
	end		
		
	if GTConfig.HealthBar == "ENABLED" then
		GameTooltipStatusBar:Show()
	elseif GTConfig.HealthBar == "DISABLED" then
		GameTooltipStatusBar:Hide()
	end
end